@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1998 by David I. Bell
+ * Copyright (c) 1999 by David I. Bell
  * Permission is granted to use, distribute, or modify this source,
  * provided that this copyright notice remains intact.
  *
@@ -9,14 +9,16 @@
 #include "sash.h"
 
 #define	USERSIZE	1024	/* max line length typed in by user */
-#define	INITBUFSIZE	1024	/* initial buffer size */
+#define	INITBUF_SIZE	1024	/* initial buffer size */
 
 
 typedef	int	NUM;
 typedef	int	LEN;
 
 typedef	struct	LINE	LINE;
-struct	LINE	{
+
+struct	LINE
+{
 	LINE *	next;
 	LINE *	prev;
 	LEN	len;
@@ -25,76 +27,73 @@ struct	LINE	{
 
 
 static	LINE	lines;
-static	LINE *	curline;
-static	NUM	curnum;
-static	NUM	lastnum;
+static	LINE *	curLine;
+static	NUM	curNum;
+static	NUM	lastNum;
 static	NUM	marks[26];
 static	BOOL	dirty;
-static	char *	filename;
-static	char	searchstring[USERSIZE];
+static	char *	fileName;
+static	char	searchString[USERSIZE];
 
-static	char *	bufbase;
-static	char *	bufptr;
-static	LEN	bufused;
-static	LEN	bufsize;
+static	char *	bufBase;
+static	char *	bufPtr;
+static	LEN	bufUsed;
+static	LEN	bufSize;
 
 
-static	void	docommands PROTO((void));
-static	void	subcommand PROTO((const char * cmd, NUM num1, NUM num2));
+static	void	doCommands(void);
+static	void	subCommand(const char * cmd, NUM num1, NUM num2);
+static	BOOL	getNum(const char ** retcp, BOOL * retHaveNum, NUM * retNum);
+static	BOOL	setCurNum(NUM num);
+static	BOOL	initEdit(void);
+static	void	termEdit(void);
+static	void	addLines(NUM num);
+static	BOOL	insertLine(NUM num, const char * data, LEN len);
+static	BOOL	deleteLines(NUM num1, NUM num2);
+static	BOOL	printLines(NUM num1, NUM num2, BOOL expandFlag);
+static	BOOL	writeLines(const char * file, NUM num1, NUM num2);
+static	BOOL	readLines(const char * file, NUM num);
+static	NUM	searchLines(const char * str, NUM num1, NUM num2);
+static	LINE *	findLine(NUM num);
 
-static	BOOL	getnum
-	PROTO((const char ** retcp, BOOL * rethavenum, NUM * retnum));
-
-static	BOOL	setcurnum PROTO((NUM num));
-static	BOOL	initedit PROTO((void));
-static	void	termedit PROTO((void));
-static	void	addlines PROTO((NUM num));
-static	BOOL	insertline PROTO((NUM num, const char * data, LEN len));
-static	BOOL	deletelines PROTO((NUM num1, NUM num2));
-static	BOOL	printlines PROTO((NUM num1, NUM num2, BOOL expandflag));
-static	BOOL	writelines PROTO((const char * file, NUM num1, NUM num2));
-static	BOOL	readlines PROTO((const char * file, NUM num));
-static	NUM	searchlines PROTO((const char * str, NUM num1, NUM num2));
-
-static	LEN	findstring
-	PROTO((const LINE * lp, const char * str, LEN len, LEN offset));
-
-static	LINE *	findline PROTO((NUM num));
+static	LEN	findString
+	(const LINE * lp, const char * str, LEN len, LEN offset);
 
 
 void
-do_ed(argc, argv)
-	int		argc;
-	const char **	argv;
+do_ed(int argc, const char ** argv)
 {
-	if (!initedit())
+	if (!initEdit())
 		return;
 
-	if (argc > 1) {
-		filename = strdup(argv[1]);
+	if (argc > 1)
+	{
+		fileName = strdup(argv[1]);
 
-		if (filename == NULL) {
+		if (fileName == NULL)
+		{
 			fprintf(stderr, "No memory\n");
-			termedit();
+			termEdit();
 
 			return;
 		}
 
-		if (!readlines(filename, 1)) {
-			termedit();
+		if (!readLines(fileName, 1))
+		{
+			termEdit();
 
 			return;
 		}
 
-		if (lastnum)
-			setcurnum(1);
+		if (lastNum)
+			setCurNum(1);
 
 		dirty = FALSE;
 	}
 
-	docommands();
+	doCommands();
 
-	termedit();
+	termEdit();
 }
 
 
@@ -102,7 +101,7 @@ do_ed(argc, argv)
  * Read commands until we are told to stop.
  */
 static void
-docommands()
+doCommands(void)
 {
 	const char *	cp;
 	char *		endbuf;
@@ -114,8 +113,9 @@ docommands()
 	BOOL		have2;
 	char		buf[USERSIZE];
 
-	while (TRUE) {
-		intflag = FALSE;
+	while (TRUE)
+	{
+		intFlag = FALSE;
 		printf(": ");
 		fflush(stdout);
 
@@ -129,116 +129,126 @@ docommands()
 
 		endbuf = &buf[len - 1];
 
-		if (*endbuf != '\n') {
+		if (*endbuf != '\n')
+		{
 			fprintf(stderr, "Command line too long\n");
 
-			do {
+			do
+			{
 				len = fgetc(stdin);
-			} while ((len != EOF) && (len != '\n'));
+			}
+			while ((len != EOF) && (len != '\n'));
 
 			continue;
 		}
 
-		while ((endbuf > buf) && isblank(endbuf[-1]))
+		while ((endbuf > buf) && isBlank(endbuf[-1]))
 			endbuf--;
 
 		*endbuf = '\0';
 
 		cp = buf;
 
-		while (isblank(*cp))
+		while (isBlank(*cp))
 			cp++;
 
 		have1 = FALSE;
 		have2 = FALSE;
 
-		if ((curnum == 0) && (lastnum > 0)) {
-			curnum = 1;
-			curline = lines.next;
+		if ((curNum == 0) && (lastNum > 0))
+		{
+			curNum = 1;
+			curLine = lines.next;
 		}
 
-		if (!getnum(&cp, &have1, &num1))
+		if (!getNum(&cp, &have1, &num1))
 			continue;
 
-		while (isblank(*cp))
+		while (isBlank(*cp))
 			cp++;
 
-		if (*cp == ',') {
+		if (*cp == ',')
+		{
 			cp++;
 
-			if (!getnum(&cp, &have2, &num2))
+			if (!getNum(&cp, &have2, &num2))
 				continue;
 
 			if (!have1)
 				num1 = 1;
 
 			if (!have2)
-				num2 = lastnum;
+				num2 = lastNum;
 
 			have1 = TRUE;
 			have2 = TRUE;
 		}
 
 		if (!have1)
-			num1 = curnum;
+			num1 = curNum;
 
 		if (!have2)
 			num2 = num1;
 
-		switch (*cp++) {
+		switch (*cp++)
+		{
 			case 'a':
-				addlines(num1 + 1);
+				addLines(num1 + 1);
 				break;
 
 			case 'c':
-				deletelines(num1, num2);
-				addlines(num1);
+				deleteLines(num1, num2);
+				addLines(num1);
 				break;
 
 			case 'd':
-				deletelines(num1, num2);
+				deleteLines(num1, num2);
 				break;
 
 			case 'f':
-				if (*cp && !isblank(*cp)) {
+				if (*cp && !isBlank(*cp))
+				{
 					fprintf(stderr, "Bad file command\n");
 					break;
 				}
 
-				while (isblank(*cp))
+				while (isBlank(*cp))
 					cp++;
 
-				if (*cp == '\0') {
-					if (filename)
-						printf("\"%s\"\n", filename);
+				if (*cp == '\0')
+				{
+					if (fileName)
+						printf("\"%s\"\n", fileName);
 					else
-						printf("No filename\n");
+						printf("No file name\n");
 
 					break;
 				}
 
 				newname = strdup(cp);
 
-				if (newname == NULL) {
-					fprintf(stderr, "No memory for filename\n");
+				if (newname == NULL)
+				{
+					fprintf(stderr, "No memory for file name\n");
 					break;
 				}
 
-				if (filename)
-					free(filename);
+				if (fileName)
+					free(fileName);
 
-				filename = newname;
+				fileName = newname;
 				break;
 
 			case 'i':
-				addlines(num1);
+				addLines(num1);
 				break;
 
 			case 'k':
-				while (isblank(*cp))
+				while (isBlank(*cp))
 					cp++;
 
-				if ((*cp < 'a') || (*cp > 'a') || cp[1]) {
+				if ((*cp < 'a') || (*cp > 'a') || cp[1])
+				{
 					fprintf(stderr, "Bad mark name\n");
 					break;
 				}
@@ -247,18 +257,19 @@ docommands()
 				break;
 
 			case 'l':
-				printlines(num1, num2, TRUE);
+				printLines(num1, num2, TRUE);
 				break;
 
 			case 'p':
-				printlines(num1, num2, FALSE);
+				printLines(num1, num2, FALSE);
 				break;
 
 			case 'q':
-				while (isblank(*cp))
+				while (isBlank(*cp))
 					cp++;
 
-				if (have1 || *cp) {
+				if (have1 || *cp)
+				{
 					fprintf(stderr, "Bad quit command\n");
 					break;
 				}
@@ -273,7 +284,7 @@ docommands()
 				fgets(buf, sizeof(buf), stdin);
 				cp = buf;
 
-				while (isblank(*cp))
+				while (isBlank(*cp))
 					cp++;
 
 				if ((*cp == 'y') || (*cp == 'Y'))
@@ -282,85 +293,91 @@ docommands()
 				break;
 
 			case 'r':
-				if (*cp && !isblank(*cp)) {
+				if (*cp && !isBlank(*cp))
+				{
 					fprintf(stderr, "Bad read command\n");
 					break;
 				}
 
-				while (isblank(*cp))
+				while (isBlank(*cp))
 					cp++;
 
-				if (*cp == '\0') {
-					fprintf(stderr, "No filename\n");
+				if (*cp == '\0')
+				{
+					fprintf(stderr, "No file name\n");
 					break;
 				}
 
 				if (!have1)
-					num1 = lastnum;
+					num1 = lastNum;
 
-				if (readlines(cp, num1 + 1))
+				if (readLines(cp, num1 + 1))
 					break;
 
-				if (filename == NULL)
-					filename = strdup(cp);
+				if (fileName == NULL)
+					fileName = strdup(cp);
 
 				break;
 
 			case 's':
-				subcommand(cp, num1, num2);
+				subCommand(cp, num1, num2);
 				break;
 
 			case 'w':
-				if (*cp && !isblank(*cp)) {
+				if (*cp && !isBlank(*cp))
+				{
 					fprintf(stderr, "Bad write command\n");
 					break;
 				}
 
-				while (isblank(*cp))
+				while (isBlank(*cp))
 					cp++;
 
 				if (!have1) {
 					num1 = 1;
-					num2 = lastnum;
+					num2 = lastNum;
 				}
 
 				if (*cp == '\0')
-					cp = filename;
+					cp = fileName;
 
-				if (cp == NULL) {
+				if (cp == NULL)
+				{
 					fprintf(stderr, "No file name specified\n");
 					break;
 				}
 	
-				writelines(cp, num1, num2);
+				writeLines(cp, num1, num2);
 				break;
 
 			case 'z':
-				switch (*cp) {
+				switch (*cp)
+				{
 				case '-':
-					printlines(curnum-21, curnum, FALSE);
+					printLines(curNum-21, curNum, FALSE);
 					break;
 				case '.':
-					printlines(curnum-11, curnum+10, FALSE);
+					printLines(curNum-11, curNum+10, FALSE);
 					break;
 				default:
-					printlines(curnum, curnum+21, FALSE);
+					printLines(curNum, curNum+21, FALSE);
 					break;
 				}
 				break;
 
 			case '.':
-				if (have1) {
+				if (have1)
+				{
 					fprintf(stderr, "No arguments allowed\n");
 					break;
 				}
 
-				printlines(curnum, curnum, FALSE);
+				printLines(curNum, curNum, FALSE);
 				break;
 	
 			case '-':
-				if (setcurnum(curnum - 1))
-					printlines(curnum, curnum, FALSE);
+				if (setCurNum(curNum - 1))
+					printLines(curNum, curNum, FALSE);
 
 				break;
 
@@ -369,13 +386,14 @@ docommands()
 				break;
 
 			case '\0':
-				if (have1) {
-					printlines(num2, num2, FALSE);
+				if (have1)
+				{
+					printLines(num2, num2, FALSE);
 					break;
 				}
 
-				if (setcurnum(curnum + 1))
-					printlines(curnum, curnum, FALSE);
+				if (setCurNum(curNum + 1))
+					printLines(curNum, curNum, FALSE);
 
 				break;
 
@@ -392,37 +410,35 @@ docommands()
  * The current line is set to the last substitution done.
  */
 static void
-subcommand(cmd, num1, num2)
-	const char *	cmd;
-	NUM		num1;
-	NUM		num2;
+subCommand(const char * cmd, NUM num1, NUM num2)
 {
 	int	delim;
 	char *	cp;
-	char *	oldstr;
-	char *	newstr;
-	LEN	oldlen;
-	LEN	newlen;
-	LEN	deltalen;
+	char *	oldStr;
+	char *	newStr;
+	LEN	oldLen;
+	LEN	newLen;
+	LEN	deltaLen;
 	LEN	offset;
 	LINE *	lp;
 	LINE *	nlp;
-	BOOL	globalflag;
-	BOOL	printflag;
-	BOOL	didsub;
-	BOOL	needprint;
+	BOOL	globalFlag;
+	BOOL	printFlag;
+	BOOL	didSub;
+	BOOL	needPrint;
 	char	buf[USERSIZE];
 
-	if ((num1 < 1) || (num2 > lastnum) || (num1 > num2)) {
+	if ((num1 < 1) || (num2 > lastNum) || (num1 > num2))
+	{
 		fprintf(stderr, "Bad line range for substitute\n");
 
 		return;
 	}
 
-	globalflag = FALSE;
-	printflag = FALSE;
-	didsub = FALSE;
-	needprint = FALSE;
+	globalFlag = FALSE;
+	printFlag = FALSE;
+	didSub = FALSE;
+	needPrint = FALSE;
 
 	/*
 	 * Copy the command so we can modify it.
@@ -430,18 +446,20 @@ subcommand(cmd, num1, num2)
 	strcpy(buf, cmd);
 	cp = buf;
 
-	if (isblank(*cp) || (*cp == '\0')) {
+	if (isBlank(*cp) || (*cp == '\0'))
+	{
 		fprintf(stderr, "Bad delimiter for substitute\n");
 
 		return;
 	}
 
 	delim = *cp++;
-	oldstr = cp;
+	oldStr = cp;
 
 	cp = strchr(cp, delim);
 
-	if (cp == NULL) {
+	if (cp == NULL)
+	{
 		fprintf(stderr, "Missing 2nd delimiter for substitute\n");
 
 		return;
@@ -449,7 +467,7 @@ subcommand(cmd, num1, num2)
 
 	*cp++ = '\0';
 
-	newstr = cp;
+	newStr = cp;
 	cp = strchr(cp, delim);
 
 	if (cp)
@@ -457,13 +475,14 @@ subcommand(cmd, num1, num2)
 	else
 		cp = "";
 
-	while (*cp) switch (*cp++) {
+	while (*cp) switch (*cp++)
+	{
 		case 'g':
-			globalflag = TRUE;
+			globalFlag = TRUE;
 			break;
 
 		case 'p':
-			printflag = TRUE;
+			printFlag = TRUE;
 			break;
 
 		default:
@@ -472,37 +491,42 @@ subcommand(cmd, num1, num2)
 			return;
 	}
 
-	if (*oldstr == '\0') {
-		if (searchstring[0] == '\0') {
+	if (*oldStr == '\0')
+	{
+		if (searchString[0] == '\0')
+		{
 			fprintf(stderr, "No previous search string\n");
 
 			return;
 		}
 
-		oldstr = searchstring;
+		oldStr = searchString;
 	}
 
-	if (oldstr != searchstring)
-		strcpy(searchstring, oldstr);
+	if (oldStr != searchString)
+		strcpy(searchString, oldStr);
 
-	lp = findline(num1);
+	lp = findLine(num1);
 
 	if (lp == NULL)
 		return;
 
-	oldlen = strlen(oldstr);
-	newlen = strlen(newstr);
-	deltalen = newlen - oldlen;
+	oldLen = strlen(oldStr);
+	newLen = strlen(newStr);
+	deltaLen = newLen - oldLen;
 	offset = 0;
 	nlp = NULL;
 
-	while (num1 <= num2) {
-		offset = findstring(lp, oldstr, oldlen, offset);
+	while (num1 <= num2)
+	{
+		offset = findString(lp, oldStr, oldLen, offset);
 
-		if (offset < 0) {
-			if (needprint) {
-				printlines(num1, num1, FALSE);
-				needprint = FALSE;
+		if (offset < 0)
+		{
+			if (needPrint)
+			{
+				printLines(num1, num1, FALSE);
+				needPrint = FALSE;
 			}
 
 			offset = 0;
@@ -512,33 +536,36 @@ subcommand(cmd, num1, num2)
 			continue;
 		}
 
-		needprint = printflag;
-		didsub = TRUE;
+		needPrint = printFlag;
+		didSub = TRUE;
 		dirty = TRUE;
 
 		/*
 		 * If the replacement string is the same size or shorter
 		 * than the old string, then the substitution is easy.
 		 */
-		if (deltalen <= 0) {
-			memcpy(&lp->data[offset], newstr, newlen);
+		if (deltaLen <= 0)
+		{
+			memcpy(&lp->data[offset], newStr, newLen);
 
-			if (deltalen) {
-				memcpy(&lp->data[offset + newlen],
-					&lp->data[offset + oldlen],
-					lp->len - offset - oldlen);
+			if (deltaLen)
+			{
+				memcpy(&lp->data[offset + newLen],
+					&lp->data[offset + oldLen],
+					lp->len - offset - oldLen);
 
-				lp->len += deltalen;
+				lp->len += deltaLen;
 			}
 
-			offset += newlen;
+			offset += newLen;
 
-			if (globalflag)
+			if (globalFlag)
 				continue;
 
-			if (needprint) {
-				printlines(num1, num1, FALSE);
-				needprint = FALSE;
+			if (needPrint)
+			{
+				printLines(num1, num1, FALSE);
+				needPrint = FALSE;
 			}
 
 			lp = lp->next;
@@ -552,51 +579,53 @@ subcommand(cmd, num1, num2)
 		 * structure and use that.  Link it in in place of
 		 * the old line structure.
 		 */
-		nlp = (LINE *) malloc(sizeof(LINE) + lp->len + deltalen);
+		nlp = (LINE *) malloc(sizeof(LINE) + lp->len + deltaLen);
 
-		if (nlp == NULL) {
+		if (nlp == NULL)
+		{
 			fprintf(stderr, "Cannot get memory for line\n");
 
 			return;
 		}
 
-		nlp->len = lp->len + deltalen;
+		nlp->len = lp->len + deltaLen;
 
 		memcpy(nlp->data, lp->data, offset);
 
-		memcpy(&nlp->data[offset], newstr, newlen);
+		memcpy(&nlp->data[offset], newStr, newLen);
 
-		memcpy(&nlp->data[offset + newlen],
-			&lp->data[offset + oldlen],
-			lp->len - offset - oldlen);
+		memcpy(&nlp->data[offset + newLen],
+			&lp->data[offset + oldLen],
+			lp->len - offset - oldLen);
 
 		nlp->next = lp->next;
 		nlp->prev = lp->prev;
 		nlp->prev->next = nlp;
 		nlp->next->prev = nlp;
 
-		if (curline == lp)
-			curline = nlp;
+		if (curLine == lp)
+			curLine = nlp;
 
 		free(lp);
 		lp = nlp;
 
-		offset += newlen;
+		offset += newLen;
 
-		if (globalflag)
+		if (globalFlag)
 			continue;
 
-		if (needprint) {
-			printlines(num1, num1, FALSE);
-			needprint = FALSE;
+		if (needPrint)
+		{
+			printLines(num1, num1, FALSE);
+			needPrint = FALSE;
 		}
 
 		lp = lp->next;
 		num1++;
 	}
 
-	if (!didsub)
-		fprintf(stderr, "No substitutions found for \"%s\"\n", oldstr);
+	if (!didSub)
+		fprintf(stderr, "No substitutions found for \"%s\"\n", oldStr);
 }
 
 
@@ -605,11 +634,7 @@ subcommand(cmd, num1, num2)
  * offset in the line.  Returns the offset of the found string, or -1.
  */
 static LEN
-findstring(lp, str, len, offset)
-	const LINE *	lp;
-	const char *	str;
-	LEN		len;
-	LEN		offset;
+findString( const LINE * lp, const char * str, LEN len, LEN offset)
 {
 	LEN		left;
 	const char *	cp;
@@ -618,7 +643,8 @@ findstring(lp, str, len, offset)
 	cp = &lp->data[offset];
 	left = lp->len - offset;
 
-	while (left >= len) {
+	while (left >= len)
+	{
 		ncp = memchr(cp, *str, left);
 
 		if (ncp == NULL)
@@ -649,13 +675,13 @@ findstring(lp, str, len, offset)
  * or by an end of file.
  */
 static void
-addlines(num)
-	NUM	num;
+addLines(NUM num)
 {
 	int	len;
 	char	buf[USERSIZE + 1];
 
-	while (fgets(buf, sizeof(buf), stdin)) {
+	while (fgets(buf, sizeof(buf), stdin))
+	{
 		if ((buf[0] == '.') && (buf[1] == '\n') && (buf[2] == '\0'))
 			return;
 
@@ -664,17 +690,20 @@ addlines(num)
 		if (len == 0)
 			return;
 
-		if (buf[len - 1] != '\n') {
+		if (buf[len - 1] != '\n')
+		{
 			fprintf(stderr, "Line too long\n");
 
-			do {
+			do
+			{
 				len = fgetc(stdin);
-			} while ((len != EOF) && (len != '\n'));
+			}
+			while ((len != EOF) && (len != '\n'));
 
 			return;
 		}
 
-		if (!insertline(num++, buf, len))
+		if (!insertLine(num++, buf, len))
 			return;
 	}
 }
@@ -689,100 +718,105 @@ addlines(num)
  * The character pointer which stopped the scan is also returned.
  */
 static BOOL
-getnum(retcp, rethavenum, retnum)
-	const char **	retcp;
-	BOOL *		rethavenum;
-	NUM *		retnum;
+getNum(const char ** retcp, BOOL * retHaveNum, NUM * retNum)
 {
 	const char *	cp;
-	char *		endstr;
+	char *		endStr;
 	char		str[USERSIZE];
-	BOOL		havenum;
+	BOOL		haveNum;
 	NUM		value;
 	NUM		num;
 	NUM		sign;
 
 	cp = *retcp;
-	havenum = FALSE;
+	haveNum = FALSE;
 	value = 0;
 	sign = 1;
 
-	while (TRUE) {
-		while (isblank(*cp))
+	while (TRUE)
+	{
+		while (isBlank(*cp))
 			cp++;
 
-		switch (*cp) {
+		switch (*cp)
+		{
 			case '.':
-				havenum = TRUE;
-				num = curnum;
+				haveNum = TRUE;
+				num = curNum;
 				cp++;
 				break;
 
 			case '$':
-				havenum = TRUE;
-				num = lastnum;
+				haveNum = TRUE;
+				num = lastNum;
 				cp++;
 				break;
 
 			case '\'':
 				cp++;
 
-				if ((*cp < 'a') || (*cp > 'z')) {
+				if ((*cp < 'a') || (*cp > 'z'))
+				{
 					fprintf(stderr, "Bad mark name\n");
 
 					return FALSE;
 				}
 
-				havenum = TRUE;
+				haveNum = TRUE;
 				num = marks[*cp++ - 'a'];
 				break;
 
 			case '/':
 				strcpy(str, ++cp);
-				endstr = strchr(str, '/');
+				endStr = strchr(str, '/');
 
-				if (endstr) {
-					*endstr++ = '\0';
-					cp += (endstr - str);
-				} else
+				if (endStr)
+				{
+					*endStr++ = '\0';
+					cp += (endStr - str);
+				}
+				else
 					cp = "";
 
-				num = searchlines(str, curnum, lastnum);
+				num = searchLines(str, curNum, lastNum);
 
 				if (num == 0)
 					return FALSE;
 
-				havenum = TRUE;
+				haveNum = TRUE;
 				break;
 
 			default:
-				if (!isdecimal(*cp)) {
+				if (!isDecimal(*cp))
+				{
 					*retcp = cp;
-					*rethavenum = havenum;
-					*retnum = value;
+					*retHaveNum = haveNum;
+					*retNum = value;
 
 					return TRUE;
 				}
 
 				num = 0;
 
-				while (isdecimal(*cp))
+				while (isDecimal(*cp))
 					num = num * 10 + *cp++ - '0';
 
-				havenum = TRUE;
+				haveNum = TRUE;
 				break;
 		}
 
 		value += num * sign;
 
-		while (isblank(*cp))
+		while (isBlank(*cp))
 			cp++;
 
-		switch (*cp) {
+		switch (*cp)
+		{
 			case '-':
 				sign = -1;
 				cp++;
 				break;
+
 			case '+':
 				sign = 1;
 				cp++;
@@ -790,8 +824,8 @@ getnum(retcp, rethavenum, retnum)
 
 			default:
 				*retcp = cp;
-				*rethavenum = havenum;
-				*retnum = value;
+				*retHaveNum = haveNum;
+				*retNum = value;
 
 				return TRUE;
 		}
@@ -803,31 +837,32 @@ getnum(retcp, rethavenum, retnum)
  * Initialize everything for editing.
  */
 static BOOL
-initedit()
+initEdit(void)
 {
 	int	i;
 
-	bufsize = INITBUFSIZE;
-	bufbase = malloc(bufsize);
+	bufSize = INITBUF_SIZE;
+	bufBase = malloc(bufSize);
 
-	if (bufbase == NULL) {
+	if (bufBase == NULL)
+	{
 		fprintf(stderr, "No memory for buffer\n");
 
 		return FALSE;
 	}
 
-	bufptr = bufbase;
-	bufused = 0;
+	bufPtr = bufBase;
+	bufUsed = 0;
 
 	lines.next = &lines;
 	lines.prev = &lines;
 
-	curline = NULL;
-	curnum = 0;
-	lastnum = 0;
+	curLine = NULL;
+	curNum = 0;
+	lastNum = 0;
 	dirty = FALSE;
-	filename = NULL;
-	searchstring[0] = '\0';
+	fileName = NULL;
+	searchString[0] = '\0';
 
 	for (i = 0; i < 26; i++)
 		marks[i] = 0;
@@ -840,29 +875,29 @@ initedit()
  * Finish editing.
  */
 static void
-termedit()
+termEdit(void)
 {
-	if (bufbase)
-		free(bufbase);
+	if (bufBase)
+		free(bufBase);
 
-	bufbase = NULL;
-	bufptr = NULL;
-	bufsize = 0;
-	bufused = 0;
+	bufBase = NULL;
+	bufPtr = NULL;
+	bufSize = 0;
+	bufUsed = 0;
 
-	if (filename)
-		free(filename);
+	if (fileName)
+		free(fileName);
 
-	filename = NULL;
+	fileName = NULL;
 
-	searchstring[0] = '\0';
+	searchString[0] = '\0';
 
-	if (lastnum)
-		deletelines(1, lastnum);
+	if (lastNum)
+		deleteLines(1, lastNum);
 
-	lastnum = 0;
-	curnum = 0;
-	curline = NULL;
+	lastNum = 0;
+	curNum = 0;
+	curLine = NULL;
 }
 
 
@@ -871,18 +906,17 @@ termedit()
  * Returns TRUE if the file was successfully read.
  */
 static BOOL
-readlines(file, num)
-	const char *	file;
-	NUM		num;
+readLines(const char * file, NUM num)
 {
 	int	fd;
 	int	cc;
 	LEN	len;
-	LEN	linecount;
-	LEN	charcount;
+	LEN	lineCount;
+	LEN	charCount;
 	char *	cp;
 
-	if ((num < 1) || (num > lastnum + 1)) {
+	if ((num < 1) || (num > lastNum + 1))
+	{
 		fprintf(stderr, "Bad line for read\n");
 
 		return FALSE;
@@ -890,97 +924,109 @@ readlines(file, num)
 
 	fd = open(file, 0);
 
-	if (fd < 0) {
+	if (fd < 0)
+	{
 		perror(file);
 
 		return FALSE;
 	}
 
-	bufptr = bufbase;
-	bufused = 0;
-	linecount = 0;
-	charcount = 0;
+	bufPtr = bufBase;
+	bufUsed = 0;
+	lineCount = 0;
+	charCount = 0;
 	cc = 0;
 
 	printf("\"%s\", ", file);
 	fflush(stdout);
 
-	do {
-		if (intflag) {
+	do
+	{
+		if (intFlag)
+		{
 			printf("INTERRUPTED, ");
-			bufused = 0;
+			bufUsed = 0;
 			break;
 		}
 
-		cp = memchr(bufptr, '\n', bufused);
+		cp = memchr(bufPtr, '\n', bufUsed);
 
-		if (cp) {
-			len = (cp - bufptr) + 1;
+		if (cp)
+		{
+			len = (cp - bufPtr) + 1;
 
-			if (!insertline(num, bufptr, len)) {
+			if (!insertLine(num, bufPtr, len))
+			{
 				close(fd);
 
 				return FALSE;
 			}
 
-			bufptr += len;
-			bufused -= len;
-			charcount += len;
-			linecount++;
+			bufPtr += len;
+			bufUsed -= len;
+			charCount += len;
+			lineCount++;
 			num++;
 
 			continue;
 		}
 
-		if (bufptr != bufbase) {
-			memcpy(bufbase, bufptr, bufused);
-			bufptr = bufbase + bufused;
+		if (bufPtr != bufBase)
+		{
+			memcpy(bufBase, bufPtr, bufUsed);
+			bufPtr = bufBase + bufUsed;
 		}
 
-		if (bufused >= bufsize) {
-			len = (bufsize * 3) / 2;
-			cp = realloc(bufbase, len);
+		if (bufUsed >= bufSize)
+		{
+			len = (bufSize * 3) / 2;
+			cp = realloc(bufBase, len);
 
-			if (cp == NULL) {
+			if (cp == NULL)
+			{
 				fprintf(stderr, "No memory for buffer\n");
 				close(fd);
 
 				return FALSE;
 			}
 
-			bufbase = cp;
-			bufptr = bufbase + bufused;
-			bufsize = len;
+			bufBase = cp;
+			bufPtr = bufBase + bufUsed;
+			bufSize = len;
 		}
 
-		cc = read(fd, bufptr, bufsize - bufused);
-		bufused += cc;
-		bufptr = bufbase;
+		cc = read(fd, bufPtr, bufSize - bufUsed);
+		bufUsed += cc;
+		bufPtr = bufBase;
 
-	} while (cc > 0);
+	}
+	while (cc > 0);
 
-	if (cc < 0) {
+	if (cc < 0)
+	{
 		perror(file);
 		close(fd);
 
 		return FALSE;
 	}
 
-	if (bufused) {
-		if (!insertline(num, bufptr, bufused)) {
+	if (bufUsed)
+	{
+		if (!insertLine(num, bufPtr, bufUsed))
+		{
 			close(fd);
 
 			return -1;
 		}
 
-		linecount++;
-		charcount += bufused;
+		lineCount++;
+		charCount += bufUsed;
 	}
 
 	close(fd);
 
-	printf("%d lines%s, %d chars\n", linecount,
-		(bufused ? " (incomplete)" : ""), charcount);
+	printf("%d lines%s, %d chars\n", lineCount,
+		(bufUsed ? " (incomplete)" : ""), charCount);
 
 	return TRUE;
 }
@@ -991,24 +1037,22 @@ readlines(file, num)
  * Returns TRUE if successful, or FALSE on an error with a message output.
  */
 static BOOL
-writelines(file, num1, num2)
-	const char *	file;
-	NUM		num1;
-	NUM		num2;
+writeLines(const char * file, NUM num1, NUM num2)
 {
 	int	fd;
 	LINE *	lp;
-	LEN	linecount;
-	LEN	charcount;
+	LEN	lineCount;
+	LEN	charCount;
 
-	if ((num1 < 1) || (num2 > lastnum) || (num1 > num2)) {
+	if ((num1 < 1) || (num2 > lastNum) || (num1 > num2))
+	{
 		fprintf(stderr, "Bad line range for write\n");
 
 		return FALSE;
 	}
 
-	linecount = 0;
-	charcount = 0;
+	lineCount = 0;
+	charCount = 0;
 
 	fd = creat(file, 0666);
 
@@ -1021,34 +1065,38 @@ writelines(file, num1, num2)
 	printf("\"%s\", ", file);
 	fflush(stdout);
 
-	lp = findline(num1);
+	lp = findLine(num1);
 
-	if (lp == NULL) {
+	if (lp == NULL)
+	{
 		close(fd);
 
 		return FALSE;
 	}
 
-	while (num1++ <= num2) {
-		if (write(fd, lp->data, lp->len) != lp->len) {
+	while (num1++ <= num2)
+	{
+		if (write(fd, lp->data, lp->len) != lp->len)
+		{
 			perror(file);
 			close(fd);
 
 			return FALSE;
 		}
 
-		charcount += lp->len;
-		linecount++;
+		charCount += lp->len;
+		lineCount++;
 		lp = lp->next;
 	}
 
-	if (close(fd) < 0) {
+	if (close(fd) < 0)
+	{
 		perror(file);
 
 		return FALSE;
 	}
 
-	printf("%d lines, %d chars\n", linecount, charcount);
+	printf("%d lines, %d chars\n", lineCount, charCount);
 
 	return TRUE;
 }
@@ -1057,35 +1105,35 @@ writelines(file, num1, num2)
 /*
  * Print lines in a specified range.
  * The last line printed becomes the current line.
- * If expandflag is TRUE, then the line is printed specially to
+ * If expandFlag is TRUE, then the line is printed specially to
  * show magic characters.
  */
 static BOOL
-printlines(num1, num2, expandflag)
-	NUM	num1;
-	NUM	num2;
-	BOOL	expandflag;
+printLines(NUM num1, NUM num2, BOOL expandFlag)
 {
 	const LINE *		lp;
 	const unsigned char *	cp;
 	int			ch;
 	LEN			count;
 
-	if ((num1 < 1) || (num2 > lastnum) || (num1 > num2)) {
+	if ((num1 < 1) || (num2 > lastNum) || (num1 > num2))
+	{
 		fprintf(stderr, "Bad line range for print\n");
 
 		return FALSE;
 	}
 
-	lp = findline(num1);
+	lp = findLine(num1);
 
 	if (lp == NULL)
 		return FALSE;
 
-	while (!intflag && (num1 <= num2)) {
-		if (!expandflag) {
+	while (!intFlag && (num1 <= num2))
+	{
+		if (!expandFlag)
+		{
 			write(STDOUT, lp->data, lp->len);
-			setcurnum(num1++);
+			setCurNum(num1++);
 			lp = lp->next;
 
 			continue;
@@ -1101,20 +1149,24 @@ printlines(num1, num2, expandflag)
 		if ((count > 0) && (cp[count - 1] == '\n'))
 			count--;
 
-		while (count-- > 0) {
+		while (count-- > 0)
+		{
 			ch = *cp++;
 
-			if (ch & 0x80) {
+			if (ch & 0x80)
+			{
 				fputs("M-", stdout);
 				ch &= 0x7f;
 			}
 
-			if (ch < ' ') {
+			if (ch < ' ')
+			{
 				fputc('^', stdout);
 				ch += '@';
 			}
 
-			if (ch == 0x7f) {
+			if (ch == 0x7f)
+			{
 				fputc('^', stdout);
 				ch = '?';
 			}
@@ -1124,7 +1176,7 @@ printlines(num1, num2, expandflag)
 
 		fputs("$\n", stdout);
 
-		setcurnum(num1++);
+		setCurNum(num1++);
 		lp = lp->next;
 	}
 
@@ -1140,52 +1192,53 @@ printlines(num1, num2, expandflag)
  * Returns TRUE if successful.
  */
 static BOOL
-insertline(num, data, len)
-	NUM		num;
-	const char *	data;
-	LEN		len;
+insertLine(NUM num, const char * data, LEN len)
 {
-	LINE *	newlp;
+	LINE *	newLp;
 	LINE *	lp;
 
-	if ((num < 1) || (num > lastnum + 1)) {
+	if ((num < 1) || (num > lastNum + 1))
+	{
 		fprintf(stderr, "Inserting at bad line number\n");
 
 		return FALSE;
 	}
 
-	newlp = (LINE *) malloc(sizeof(LINE) + len - 1);
+	newLp = (LINE *) malloc(sizeof(LINE) + len - 1);
 
-	if (newlp == NULL)  {
+	if (newLp == NULL) 
+	{
 		fprintf(stderr, "Failed to allocate memory for line\n");
 
 		return FALSE;
 	}
 
-	memcpy(newlp->data, data, len);
-	newlp->len = len;
+	memcpy(newLp->data, data, len);
+	newLp->len = len;
 
-	if (num > lastnum)
+	if (num > lastNum)
 		lp = &lines;
-	else {
-		lp = findline(num);
+	else
+	{
+		lp = findLine(num);
 
-		if (lp == NULL) {
-			free((char *) newlp);
+		if (lp == NULL)
+		{
+			free((char *) newLp);
 
 			return FALSE;
 		}
 	}
 
-	newlp->next = lp;
-	newlp->prev = lp->prev;
-	lp->prev->next = newlp;
-	lp->prev = newlp;
+	newLp->next = lp;
+	newLp->prev = lp->prev;
+	lp->prev->next = newLp;
+	lp->prev = newLp;
 
-	lastnum++;
+	lastNum++;
 	dirty = TRUE;
 
-	return setcurnum(num);
+	return setCurNum(num);
 }
 
 
@@ -1193,43 +1246,44 @@ insertline(num, data, len)
  * Delete lines from the given range.
  */
 static BOOL
-deletelines(num1, num2)
-	NUM	num1;
-	NUM	num2;
+deleteLines(NUM num1, NUM num2)
 {
 	LINE *	lp;
 	LINE *	nlp;
 	LINE *	plp;
 	NUM	count;
 
-	if ((num1 < 1) || (num2 > lastnum) || (num1 > num2)) {
+	if ((num1 < 1) || (num2 > lastNum) || (num1 > num2))
+	{
 		fprintf(stderr, "Bad line numbers for delete\n");
 
 		return FALSE;
 	}
 
-	lp = findline(num1);
+	lp = findLine(num1);
 
 	if (lp == NULL)
 		return FALSE;
 
-	if ((curnum >= num1) && (curnum <= num2)) {
-		if (num2 < lastnum)
-			setcurnum(num2 + 1);
+	if ((curNum >= num1) && (curNum <= num2))
+	{
+		if (num2 < lastNum)
+			setCurNum(num2 + 1);
 		else if (num1 > 1)
-			setcurnum(num1 - 1);
+			setCurNum(num1 - 1);
 		else
-			curnum = 0;
+			curNum = 0;
 	}
 
 	count = num2 - num1 + 1;
 
-	if (curnum > num2)
-		curnum -= count;
+	if (curNum > num2)
+		curNum -= count;
 
-	lastnum -= count;
+	lastNum -= count;
 
-	while (count-- > 0) {
+	while (count-- > 0)
+	{
 		nlp = lp->next;
 		plp = lp->prev;
 		plp->next = nlp;
@@ -1255,42 +1309,43 @@ deletelines(num1, num2)
  * with an error printed.
  */
 static NUM
-searchlines(str, num1, num2)
-	const char *	str;
-	NUM		num1;
-	NUM		num2;
+searchLines(const char * str, NUM num1, NUM num2)
 {
 	const LINE *	lp;
 	int		len;
 
-	if ((num1 < 1) || (num2 > lastnum) || (num1 > num2)) {
+	if ((num1 < 1) || (num2 > lastNum) || (num1 > num2))
+	{
 		fprintf(stderr, "Bad line numbers for search\n");
 
 		return 0;
 	}
 
-	if (*str == '\0') {
-		if (searchstring[0] == '\0') {
+	if (*str == '\0')
+	{
+		if (searchString[0] == '\0')
+		{
 			fprintf(stderr, "No previous search string\n");
 
 			return 0;
 		}
 
-		str = searchstring;
+		str = searchString;
 	}
 
-	if (str != searchstring)
-		strcpy(searchstring, str);
+	if (str != searchString)
+		strcpy(searchString, str);
 
 	len = strlen(str);
 
-	lp = findline(num1);
+	lp = findLine(num1);
 
 	if (lp == NULL)
 		return 0;
 
-	while (num1 <= num2) {
-		if (findstring(lp, str, len, 0) >= 0)
+	while (num1 <= num2)
+	{
+		if (findString(lp, str, len, 0) >= 0)
 			return num1;
 
 		num1++;
@@ -1307,44 +1362,49 @@ searchlines(str, num1, num2)
  * Return a pointer to the specified line number.
  */
 static LINE *
-findline(num)
-	NUM	num;
+findLine(NUM num)
 {
 	LINE *	lp;
 	NUM	lnum;
 
-	if ((num < 1) || (num > lastnum)) {
+	if ((num < 1) || (num > lastNum))
+	{
 		fprintf(stderr, "Line number %d does not exist\n", num);
 
 		return NULL;
 	}
 
-	if (curnum <= 0) {
-		curnum = 1;
-		curline = lines.next;
+	if (curNum <= 0)
+	{
+		curNum = 1;
+		curLine = lines.next;
 	}
 
-	if (num == curnum)
-		return curline;
+	if (num == curNum)
+		return curLine;
 
-	lp = curline;
-	lnum = curnum;
+	lp = curLine;
+	lnum = curNum;
 
-	if (num < (curnum / 2)) {
+	if (num < (curNum / 2))
+	{
 		lp = lines.next;
 		lnum = 1;
 	}
-	else if (num > ((curnum + lastnum) / 2)) {
+	else if (num > ((curNum + lastNum) / 2))
+	{
 		lp = lines.prev;
-		lnum = lastnum;
+		lnum = lastNum;
 	}
 
-	while (lnum < num) {
+	while (lnum < num)
+	{
 		lp = lp->next;
 		lnum++;
 	}
 
-	while (lnum > num) {
+	while (lnum > num)
+	{
 		lp = lp->prev;
 		lnum--;
 	}
@@ -1358,18 +1418,17 @@ findline(num)
  * Returns TRUE if successful.
  */
 static BOOL
-setcurnum(num)
-	NUM	num;
+setCurNum(NUM num)
 {
 	LINE *	lp;
 
-	lp = findline(num);
+	lp = findLine(num);
 
 	if (lp == NULL)
 		return FALSE;
 
-	curnum = num;
-	curline = lp;
+	curNum = num;
+	curLine = lp;
 
 	return TRUE;
 }
